@@ -12,7 +12,7 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, List
+from typing import Any, Dict, Sequence
 
 if sys.version_info >= (3, 8):
     from typing import TypedDict
@@ -44,7 +44,7 @@ _OptionalCreateTokenRequestRequestTypeDef = TypedDict(
     {
         "code": str,
         "refreshToken": str,
-        "scope": List[str],
+        "scope": Sequence[str],
         "redirectUri": str,
     },
     total=False,
@@ -79,7 +79,7 @@ _RequiredRegisterClientRequestRequestTypeDef = TypedDict(
 _OptionalRegisterClientRequestRequestTypeDef = TypedDict(
     "_OptionalRegisterClientRequestRequestTypeDef",
     {
-        "scopes": List[str],
+        "scopes": Sequence[str],
     },
     total=False,
 )
